@@ -45,7 +45,7 @@ use warnings;
 use UMLS::Similarity;
 
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = '0.05';
 
 my $debug = 0;
 
@@ -59,24 +59,10 @@ sub new
     my $interface = shift;
 
     my $self = {};
-    
-    # Initialize the error string and the error level.
-    $self->{'errorString'} = "";
-    $self->{'error'} = 0;
- 
-   # Bless the object.
+     
+    # Bless the object.
     bless($self, $className);
     
-    # The backend interface object.
-    $self->{'interface'} = $interface;
-
-    if(!$interface)
-    {
-	$self->{'errorString'} .= "\nError (UMLS::Similarity::random->new()) - ";
-	$self->{'errorString'} .= "An interface object is required.";
-	$self->{'error'} = 2;
-    }
-
     # The backend interface object.
     $self->{'interface'} = $interface;
     
@@ -99,26 +85,6 @@ sub getRelatedness
     return $score
 }
 
-# Method to return recent error/warning condition
-sub getError
-{
-    my $self = shift;
-    return (2, "") if(!defined $self || !ref $self);
-
-    if($debug) { print STDERR "In UMLS::Similarity::random->getError()\n"; }
-
-    my $dontClear = shift;
-    my $error = $self->{'error'};
-    my $errorString = $self->{'errorString'};
-
-    if(!(defined $dontClear && $dontClear)) {
-	$self->{'error'} = 0;
-	$self->{'errorString'} = "";
-    }
-    $errorString =~ s/^\n//;
-
-    return ($error, $errorString);
-}
 1;
 __END__
 
@@ -130,23 +96,27 @@ by assigning a random number between zero and one as the similarity score.
 =head1 SYNOPSIS
 
   use UMLS::Interface;
+
   use UMLS::Similarity::random;
 
   my $umls = UMLS::Interface->new(); 
+
   die "Unable to create UMLS::Interface object.\n" if(!$umls);
-  ($errCode, $errString) = $umls->getError();
-  die "$errString\n" if($errCode);
 
   my $random = UMLS::Similarity::random->new($umls);
+
   die "Unable to create measure object.\n" if(!$random);
-  
+
   my $cui1 = "C0005767";
+
   my $cui2 = "C0007634";
-	
+
   @ts1 = $umls->getTermList($cui1);
+
   my $term1 = pop @ts1;
 
   @ts2 = $umls->getTermList($cui2);
+
   my $term2 = pop @ts2;
 
   my $value = $random->getRelatedness($cui1, $cui2);
@@ -164,7 +134,6 @@ The semantic relatedness modules in this distribution are built as classes
 that expose the following methods:
   new()
   getRelatedness()
-  getError()
 
 =head1 TYPICAL USAGE EXAMPLES
 
@@ -179,41 +148,20 @@ variable '$measure'. '$interface' contains an interface object that
 should have been created earlier in the program (UMLS-Interface). 
 
 If the 'new' method is unable to create the object, '$measure' would 
-be undefined. This, as well as any other error/warning may be tested.
-
-   die "Unable to create object.\n" if(!defined $measure);
-   ($err, $errString) = $measure->getError();
-   die $errString."\n" if($err);
+be undefined. 
 
 To find the semantic relatedness of the concept 'blood' (C0005767) and
 the concept 'cell' (C0007634) using the measure, we would write
 the following piece of code:
 
    $relatedness = $measure->getRelatedness('C0005767', 'C0007634');
-  
+
 =head1 SEE ALSO
 
 perl(1), UMLS::Interface
 
 perl(1), UMLS::Similarity(3)
 
-=head1 CONTACT US
-   
-  If you have any trouble installing and using UMLS-Similarity, 
-  please contact us via the users mailing list :
-    
-      umls-similarity@yahoogroups.com
-     
-  You can join this group by going to:
-    
-      http://tech.groups.yahoo.com/group/umls-similarity/
-     
-  You may also contact us directly if you prefer :
-    
-      Bridget T. McInnes: bthomson at cs.umn.edu 
-
-      Ted Pedersen : tpederse at d.umn.edu
-
 =head1 AUTHORS
 
   Bridget T McInnes <bthomson at cs.umn.edu>
